## Roguelike Specific Elements

### Run Structure

{{run_structure}}

**Run design:**

- Run length (time, stages)
- Starting conditions
- Difficulty scaling per run
- Victory conditions

### Procedural Generation

{{procedural_generation}}

**Generation systems:**

- Level generation algorithm
- Enemy placement
- Item/loot distribution
- Biome/theme variation
- Seed system (if deterministic)

### Permadeath and Progression

{{permadeath_progression}}

**Death mechanics:**

- Permadeath rules
- What persists between runs
- Meta-progression systems
- Unlock conditions

### Item and Upgrade System

{{item_upgrade_system}}

**Item mechanics:**

- Item types (passive, active, consumable)
- Rarity system
- Item synergies
- Build variety
- Curse/risk mechanics

### Character Selection

{{character_selection}}

**Playable characters:**

- Starting characters
- Unlockable characters
- Character unique abilities
- Character playstyle differences

### Difficulty Modifiers

{{difficulty_modifiers}}

**Challenge systems:**

- Difficulty tiers
- Modifiers/curses
- Challenge runs
- Achievement conditions
